@@ -134,10 +134,10 @@ INPUT_FORMATS = {
 #  C - Alpha, optional
 
 INPUT_CHAR_MAP = {
-    INPUT_ASCII_LETTER:     lambda text: text in string.ascii_letters,
-    INPUT_ALPHA:            unicode.isalpha,
-    INPUT_ALPHANUMERIC:     unicode.isalnum,
-    INPUT_DIGIT:            unicode.isdigit,
+    INPUT_ASCII_LETTER: lambda text: text in string.ascii_letters,
+    INPUT_ALPHA: unicode.isalpha,
+    INPUT_ALPHANUMERIC: unicode.isalnum,
+    INPUT_DIGIT: unicode.isdigit,
     }
 
 
@@ -150,6 +150,7 @@ INPUT_CHAR_MAP = {
 
 _ = lambda msg: gettext.dgettext('kiwi', msg)
 
+
 class KiwiEntry(gtk.Entry):
     """
     The KiwiEntry is a Entry subclass with the following additions:
@@ -235,7 +236,7 @@ class KiwiEntry(gtk.Entry):
         try:
             self.set_mask(value)
             return self.get_mask()
-        except MaskError, e:
+        except MaskError:
             pass
     mask = gobject.property(getter=_get_mask,
                             setter=_set_mask,
@@ -265,7 +266,6 @@ class KiwiEntry(gtk.Entry):
 
         self._really_delete_text(0, -1)
         if not self._mask:
-            new_text = text
             self._really_insert_text(text, 0)
             return
 
@@ -292,7 +292,7 @@ class KiwiEntry(gtk.Entry):
                 to_insert[pos] = t
 
         self._really_insert_text(''.join(to_insert), 0)
-        self.set_position(pos+1)
+        self.set_position(pos + 1)
 
     # Mask & Fields
 
@@ -327,7 +327,6 @@ class KiwiEntry(gtk.Entry):
 
         mask = unicode(mask)
         input_length = len(mask)
-        lenght = 0
         pos = 0
         field_begin = 0
         field_end = 0
@@ -429,7 +428,7 @@ class KiwiEntry(gtk.Entry):
     def _get_field_ideal_pos(self, field):
         start, end = self._mask_fields[field]
         text = self.get_field_text(field)
-        pos = start+len(text)
+        pos = start + len(text)
         return pos
 
     def get_field(self):
@@ -446,7 +445,6 @@ class KiwiEntry(gtk.Entry):
         self.set_position(pos)
 
         if select:
-            field_text = self.get_field_text(field)
             start, end = self._mask_fields[field]
             self.select_region(start, pos)
 
@@ -492,7 +490,7 @@ class KiwiEntry(gtk.Entry):
                 # Otherwise, when shifting right, the char will be
                 # prepended.
                 next_pos = self._get_next_non_static_char_pos(i, direction,
-                                                              positions-1)
+                                                              positions - 1)
 
                 # If its outside the bounds of the region, ignore it.
                 if not start <= next_pos <= end:
@@ -512,9 +510,9 @@ class KiwiEntry(gtk.Entry):
             else:
                 # Keep the static char where it is.
                 if direction == Direction.LEFT:
-                   new_text = new_text + text[i]
+                    new_text = new_text + text[i]
                 else:
-                   new_text = text[i] + new_text
+                    new_text = text[i] + new_text
             i += direction
 
         return new_text
@@ -528,7 +526,7 @@ class KiwiEntry(gtk.Entry):
         """
         text = self.get_text()
         validators = self._mask_validators
-        i = pos+direction+skip
+        i = pos + direction + skip
         while 0 <= i < len(text):
             if isinstance(validators[i], int):
                 return i
@@ -765,7 +763,7 @@ class KiwiEntry(gtk.Entry):
         # position after that static char.
         if (self._confirms_to_mask(pos, new) and
             not isinstance(validators[pos], int)):
-            return pos+1
+            return pos + 1
 
         # If does not confirms to mask:
         #  - Check if the char the user just tried to enter appers later.
@@ -773,7 +771,7 @@ class KiwiEntry(gtk.Entry):
         if not self._confirms_to_mask(pos, new):
             field = self._appers_later(new, pos)
             if field is not False:
-                pos = self.get_field_pos(field+1)
+                pos = self.get_field_pos(field + 1)
                 if pos is not None:
                     gobject.idle_add(self.set_position, pos)
             return pos
@@ -793,7 +791,6 @@ class KiwiEntry(gtk.Entry):
                     and the new text.
         """
         field = self._get_field_at_pos(pos)
-        length = len(new)
         new_pos = pos
         start, end = self._mask_fields[field]
 
@@ -803,16 +800,17 @@ class KiwiEntry(gtk.Entry):
                     text[end:])
 
         # Overwrite Right
-#        new_text = (text[:pos] + new +
-#                    text[pos+length:end]+
-#                    text[end:])
-        new_pos = pos+1
+        #length = len(new)
+        #new_text = (text[:pos] + new +
+        #            text[pos+length:end]+
+        #            text[end:])
+        new_pos = pos + 1
         gobject.idle_add(self.set_position, new_pos)
 
         # If the field is full, jump to the next field
-        if len(self.get_field_text(field)) == self.get_field_length(field)-1:
-            gobject.idle_add(self.set_field, field+1, True)
-            self.set_field(field+1)
+        if len(self.get_field_text(field)) == self.get_field_length(field) - 1:
+            gobject.idle_add(self.set_field, field + 1, True)
+            self.set_field(field + 1)
 
         return new_pos, new_text
 
@@ -830,8 +828,8 @@ class KiwiEntry(gtk.Entry):
             else:
                 self._icon_pos = gtk.POS_LEFT
 
-
     # Callbacks
+
     def _on_insert_text(self, editable, new, length, position):
         if not self._mask or self._block_insert:
             return
@@ -867,16 +865,16 @@ class KiwiEntry(gtk.Entry):
         if (0 < start < len(self._mask_validators)
             and not isinstance(self._mask_validators[start], int)
             and pos != start):
-            self._on_delete_text(editable, start-1, start)
+            self._on_delete_text(editable, start - 1, start)
             return
 
         # we just tried to delete, stop the selection.
         self._selecting = False
 
-        field = self._get_field_at_pos(end-1)
+        field = self._get_field_at_pos(end - 1)
         # Outside a field. Cannot delete.
         if field is None:
-            self.set_position(end-1)
+            self.set_position(end - 1)
             return
         _start, _end = self._mask_fields[field]
 
@@ -890,16 +888,16 @@ class KiwiEntry(gtk.Entry):
         # Shift Left
         new_text = (text[:start] +
                     self._shift_text(start, _end, Direction.LEFT,
-                                     end-start) +
+                                     end - start) +
                     text[_end:])
 
         # Overwrite Left
-#        empty_mask = self.get_empty_mask()
-#        new_text = (text[:_start] +
-#                    text[_start:start] +
-#                    empty_mask[start:start+(end-start)] +
-#                    text[start+(end-start):_end] +
-#                    text[_end:])
+        #empty_mask = self.get_empty_mask()
+        #new_text = (text[:_start] +
+        #            text[_start:start] +
+        #            empty_mask[start:start+(end-start)] +
+        #            text[start+(end-start):_end] +
+        #            text[_end:])
 
         new_pos = start
 
@@ -942,7 +940,7 @@ class KiwiEntry(gtk.Entry):
             return False
 
         if field < 0:
-            field = len(self._mask_fields)-1
+            field = len(self._mask_fields) - 1
 
         # grab_focus changes the selection, so we need to grab_focus before
         # making the selection.
@@ -1153,9 +1151,11 @@ class KiwiEntry(gtk.Entry):
 
 type_register(KiwiEntry)
 
+
 def main(args):
     win = gtk.Window()
     win.set_title('gtk.Entry subclass')
+
     def cb(window, event):
         print 'fields', widget.get_field_text()
         gtk.main_quit()
